@@ -27,14 +27,14 @@
 #' @examples
 #' # Exact search
 #'
-#' x <- list(p1 = list(type="A",score=c(c1=9)),
-#'        p2 = list(type=c("A","B"),score=c(c1=8,c2=9)),
-#'        p3 = list(type=c("B","C"),score=c(c1=9,c2=7)),
-#'        p4 = list(type=c("B","C"),score=c(c1=8,c2=NA)))
+#' x <- list(p1 = list(type='A',score=c(c1=9)),
+#'        p2 = list(type=c('A','B'),score=c(c1=8,c2=9)),
+#'        p3 = list(type=c('B','C'),score=c(c1=9,c2=7)),
+#'        p4 = list(type=c('B','C'),score=c(c1=8,c2=NA)))
 #'
 #' ## Search exact values
-#' list.search(x, identical(., "A"))
-#' list.search(x, identical(., c("A","B")))
+#' list.search(x, identical(., 'A'))
+#' list.search(x, identical(., c('A','B')))
 #' list.search(x, identical(., c(9,7)))
 #' list.search(x, identical(., c(c1=9,c2=7)))
 #'
@@ -50,49 +50,49 @@
 #' # Fuzzy search
 #'
 #' data <- list(
-#'   p1 = list(name="Ken",age=24),
-#'   p2 = list(name="Kent",age=26),
-#'   p3 = list(name="Sam",age=24),
-#'   p4 = list(name="Keynes",age=30),
-#'   p5 = list(name="Kwen",age=31)
+#'   p1 = list(name='Ken',age=24),
+#'   p2 = list(name='Kent',age=26),
+#'   p3 = list(name='Sam',age=24),
+#'   p4 = list(name='Keynes',age=30),
+#'   p5 = list(name='Kwen',age=31)
 #' )
 #'
-#' list.search(data, grepl("^K\\w+n$", .), "character")
+#' list.search(data, grepl('^K\\w+n$', .), 'character')
 #'
 #' \dontrun{
 #' library(stringdist)
-#' list.search(data, stringdist(., "Ken") <= 1, "character")
-#' list.search(data, stringdist(., "Man") <= 2, "character")
-#' list.search(data, stringdist(., "Man") > 2, "character")
+#' list.search(data, stringdist(., 'Ken') <= 1, 'character')
+#' list.search(data, stringdist(., 'Man') <= 2, 'character')
+#' list.search(data, stringdist(., 'Man') > 2, 'character')
 #' }
 #'
 #' data <- list(
-#'   p1 = list(name=c("Ken", "Ren"),age=24),
-#'   p2 = list(name=c("Kent", "Potter"),age=26),
-#'   p3 = list(name=c("Sam", "Lee"),age=24),
-#'   p4 = list(name=c("Keynes", "Bond"),age=30),
-#'   p5 = list(name=c("Kwen", "Hu"),age=31))
+#'   p1 = list(name=c('Ken', 'Ren'),age=24),
+#'   p2 = list(name=c('Kent', 'Potter'),age=26),
+#'   p3 = list(name=c('Sam', 'Lee'),age=24),
+#'   p4 = list(name=c('Keynes', 'Bond'),age=30),
+#'   p5 = list(name=c('Kwen', 'Hu'),age=31))
 #'
-#' list.search(data, .[grepl("e", .)], "character")
+#' list.search(data, .[grepl('e', .)], 'character')
 #'
 #' \dontrun{
-#' list.search(data, all(stringdist(., "Ken") <= 1), "character")
-#' list.search(data, any(stringdist(., "Ken") > 1), "character")
+#' list.search(data, all(stringdist(., 'Ken') <= 1), 'character')
+#' list.search(data, any(stringdist(., 'Ken') > 1), 'character')
 #' }
 list.search <- function(.data, expr, classes = "ANY", n, unlist = FALSE) {
   vec <- rapply(.data, function(x) TRUE, classes = classes)
-  if(missing(n)) n <- sum(vec)
+  if (missing(n)) 
+    n <- sum(vec)
   l <- lambda(substitute(expr))
-  args <- args_env(i = 0L, n = 0L, N = n,
-    indices = integer(n), result = vector("list", n))
+  args <- args_env(i = 0L, n = 0L, N = n, indices = integer(n), result = vector("list", 
+    n))
   fun <- list.search.fun
   environment(fun) <- parent.frame()
-  formals(fun) <- setnames(formals(fun),
-    c(".data",".expr",".args", ".n", l$symbols))
-  try(rapply(.data, fun, classes = classes,
-    .expr = l$expr, .args = args), silent = TRUE)
-  result <- list.clean(args$result, is.null, recursive = FALSE)
+  formals(fun) <- setnames(formals(fun), c(".data", ".expr", ".args", ".n", l$symbols))
+  try(rapply(.data, fun, classes = classes, .expr = l$expr, .args = args), silent = TRUE)
+  result <- list.clean(args$result, recursive = FALSE)
   names(result) <- names(vec)[args$indices]
-  if(unlist) result <- unlist(result)
+  if (unlist) 
+    result <- c(result, recursive = TRUE)
   result
-}
+} 
